@@ -5,9 +5,8 @@
 from __future__ import absolute_import, division, print_function
 
 import os
-import sys
 
-from _cffi_src.utils import build_ffi, extra_link_args
+from _cffi_src.utils import build_ffi, compiler_type, extra_link_args
 
 
 with open(os.path.join(
@@ -24,5 +23,5 @@ ffi = build_ffi(
     module_name="_constant_time",
     cdef_source=types,
     verify_source=functions,
-    extra_link_args=extra_link_args(sys.platform),
+    extra_link_args=extra_link_args(compiler_type()),
 )
