@@ -9,8 +9,6 @@ INCLUDES = """
 """
 
 TYPES = """
-static const long Cryptography_HAS_ENGINE_CRYPTODEV;
-
 typedef ... ENGINE;
 typedef ... RSA_METHOD;
 typedef ... DSA_METHOD;
@@ -125,22 +123,11 @@ const ENGINE_CMD_DEFN *ENGINE_get_cmd_defns(const ENGINE *);
 EVP_PKEY *ENGINE_load_private_key(ENGINE *, const char *, UI_METHOD *, void *);
 EVP_PKEY *ENGINE_load_public_key(ENGINE *, const char *, UI_METHOD *, void *);
 void ENGINE_add_conf_module(void);
-"""
-
-MACROS = """
 /* these became macros in 1.1.0 */
 void ENGINE_load_openssl(void);
 void ENGINE_load_dynamic(void);
 void ENGINE_cleanup(void);
-
-void ENGINE_load_cryptodev(void);
 """
 
 CUSTOMIZATIONS = """
-#if CRYPTOGRAPHY_IS_LIBRESSL
-static const long Cryptography_HAS_ENGINE_CRYPTODEV = 0;
-void (*ENGINE_load_cryptodev)(void) = NULL;
-#else
-static const long Cryptography_HAS_ENGINE_CRYPTODEV = 1;
-#endif
 """
