@@ -575,7 +575,10 @@ class TestDSAVerification(object):
             y=vector['y']
         ).public_key(backend)
         sig = encode_dss_signature(vector['r'], vector['s'])
-        verifier = public_key.verifier(sig, algorithm())
+        verifier = pytest.deprecated_call(
+            public_key.verifier, sig, algorithm()
+        )
+
         verifier.update(vector['msg'])
         if vector['result'] == "F":
             with pytest.raises(InvalidSignature):
@@ -638,6 +641,18 @@ class TestDSAVerification(object):
         with pytest.raises(ValueError):
             public_key.verify(b"\x00" * 128, digest, prehashed_alg)
 
+    def test_prehashed_unsupported_in_signer_ctx(self, backend):
+        private_key = DSA_KEY_1024.private_key(backend)
+        with pytest.raises(TypeError):
+            private_key.signer(Prehashed(hashes.SHA1()))
+
+    def test_prehashed_unsupported_in_verifier_ctx(self, backend):
+        public_key = DSA_KEY_1024.private_key(backend).public_key()
+        with pytest.raises(TypeError):
+            public_key.verifier(
+                b"0" * 64, Prehashed(hashes.SHA1())
+            )
+
 
 @pytest.mark.requires_backend_interface(interface=DSABackend)
 class TestDSASignature(object):
@@ -673,7 +688,7 @@ class TestDSASignature(object):
             ),
             x=vector['x']
         ).private_key(backend)
-        signer = private_key.signer(algorithm())
+        signer = pytest.deprecated_call(private_key.signer, algorithm())
         signer.update(vector['msg'])
         signature = signer.finalize()
         assert signature
